@@ -193,7 +193,8 @@ AddDictTab( dict );
 
 void TMainWindow::Load()
 {
-QString filePath = QFileDialog::getOpenFileName(this, tr("Load dictionary"), iWorkPath);
+QString filePath = QFileDialog::getOpenFileName( this, tr("Load dictionary"), iWorkPath,
+                                                 tr("Dictionaries (*.fmd);;All files (*)") );
 if( filePath.isEmpty() )
     return;
 iWorkPath = QFileInfo( filePath ).path();
@@ -283,7 +284,8 @@ if( !dict )
 QString filePath = dict->FilePath();
 if( filePath.isEmpty() )
     filePath = iWorkPath + "/" + TDictionary::KNoName;
-filePath = QFileDialog::getSaveFileName(this, tr("Save dictionary as ..."), filePath);
+filePath = QFileDialog::getSaveFileName(this, tr("Save dictionary as ..."), filePath,
+                                        tr("Dictionaries (*.fmd);;All files (*)"));
 if( filePath.isEmpty() )
     return false;
 iWorkPath = QFileInfo( filePath ).path();
@@ -303,7 +305,8 @@ SaveAs( false );    // Do not change the file name
 
 void TMainWindow::Import()
 {
-QString filePath = QFileDialog::getOpenFileName(this, tr("Import CSV file"), iWorkPath);
+QString filePath = QFileDialog::getOpenFileName(this, tr("Import CSV file"), iWorkPath,
+                                                tr("CSV files (*.csv *.txt);;All files (*)"));
 if( filePath.isEmpty() )
     return;
 iWorkPath = QFileInfo( filePath ).path();
@@ -326,7 +329,8 @@ if( exportDialog.exec() )
     QString dictFilePath( dict->FilePath() );
     if( dictFilePath.isEmpty() )
         dictFilePath = iWorkPath + "/" + TDictionary::KNoName;
-    QString filePath = QFileDialog::getSaveFileName( this, tr("Export to CSV file"), dictFilePath + ".txt" );
+    QString filePath = QFileDialog::getSaveFileName( this, tr("Export to CSV file"), dictFilePath + ".txt",
+                                                     tr("CSV files (*.csv *.txt);;All files (*)") );
     if( filePath.isEmpty() )
         return;
     iWorkPath = QFileInfo( filePath ).path();
